@@ -438,9 +438,6 @@ def getloansurl(idcred, *args, **kwargs):
     * branchId
     * centreId
     * creditOfficerUsername
-    * fixedDaysOfMonth
-    * startDate
-    * endDate
     * limit
     * offset
 
@@ -474,18 +471,6 @@ def getloansurl(idcred, *args, **kwargs):
             getparams.append("creditOfficerUsername=%s" % kwargs["creditOfficerUsername"])
         except Exception as ex:
             pass
-        try:
-            getparams.append("startDate=%s" % kwargs["startDate"])
-        except Exception as ex:
-            pass
-        try:
-            getparams.append("endDate=%s" % kwargs["endDate"])
-        except Exception as ex:
-            pass
-        try:
-            getparams.append("fixedDaysOfMonth=%s" % kwargs["fixedDaysOfMonth"])
-        except Exception as ex:
-            pass
         try:
             getparams.append("offset=%s" % kwargs["offset"])
         except Exception as ex:
@@ -1000,6 +985,16 @@ def getrolesurl(idrole='', *args, **kwargs):
     url = getmambuurl(*args,**kwargs) + "userroles" + (("/" + idrole) if idrole else "")
     return url
 
+def getpostdocumentsurl(identity="", *args, **kwargs):
+    """Request to post documents URL.
+
+    See Mambu official developer documentation for further details.
+    https://support.mambu.com/docs/attachments-api
+
+    """
+    url = getmambuurl(*args,**kwargs) + "documents"
+    return url
+
 ### No more urlfuncs from here ###
 
 ### More utility functions follow ###
